const char *mime_types[] = {
    "audio/x-musepack",
    "application/x-musepack",
    "audio/musepack",
    "application/musepack",
    "application/x-ape",
    "audio/ape",
    "audio/x-ape",
    "audio/x-mp3",
    "application/x-id3",
    "audio/mpeg",
    "audio/x-mpeg",
    "audio/x-mpeg-3",
    "audio/mpeg3",
    "audio/mp3",
    "audio/mp4",
    "audio/x-m4a",
    "audio/mpc",
    "audio/x-mpc",
    "audio/mp",
    "audio/x-mp",
    "application/ogg",
    "application/x-ogg",
    "application/x-vorbis+ogg",
    "audio/x-vorbis+ogg",
    "audio/vorbis",
    "audio/x-vorbis",
    "audio/ogg",
    "audio/x-ogg",
    "audio/x-flac",
    "application/x-flac",
    "audio/flac",
    "audio/x-s3m",
    "audio/x-mod",
    "audio/x-xm",
    "audio/x-it",
    "video/quicktime",
    "video/x-quicktime",
    "application/x-quicktimeplayer",
    "application/smil",
    "audio/x-pn-realaudio",
    "application/vnd.rn-realmedia",
    "application/vnd.rn-realaudio",
    "video/vnd.rn-realvideo",
    "audio/x-realaudio",
    "audio/x-pn-realaudio-plugin",
    "application/asx",
    "video/x-ms-asf-plugin",
    "video/x-msvideo",
    "video/msvideo",
    "application/x-mplayer2",
    "application/x-ms-wmv",
    "video/x-ms-asf",
    "video/x-ms-wm",
    "video/x-ms-wmv",
    "audio/x-ms-wmv",
    "video/x-ms-wmp",
    "video/x-ms-wvx",
    "audio/x-ms-wax",
    "audio/x-ms-wma",
    "application/x-drm-v2",
    "audio/wav",
    "audio/x-wav",
    "video/mpeg",
    "video/x-mpeg",
    "video/x-mpeg2",
    "audio/mpeg2",
    "audio/x-mpeg2",
    "video/mp4",
    "video/3gpp",
    "audio/x-mpeg3",
    "audio/x-mpegurl",
    "video/fli",
    "video/x-fli",
    "video/x-flv",
    "video/vnd.vivo",
    "application/x-nsv-vp3-mp3",
    "audio/basic",
    "audio/x-basic",
    "audio/midi",
    "audio/x-scpls",
    "video/x-matroska",
    "video/matroska",
    "audio/webm",
    "audio/x-webm",
    "video/webm",
    "video/x-webm",
    "application/x-extension-webm",
    "video/mp2t",
    "video/vnd.mpegurl",
    "video/x-mpegurl",
};
